// First test piece for something to attach to the magnets: A simple
// hook, longer that the short little store bought hooks I have now which
// the dish towels keep falling off of. Designed to go on the first
// "mag1" magnet shape.

include <connector.scad>

hook_width=15;
hook_length=40;
angle=35;
radius=50;
end_x = radius * cos(angle);
end_y = radius * sin(angle);
slot_height=52;

// Shape to cut out of hook_body so it will merge properly with the top
// and front, leaving no holes, nor poking through anywhere.
//
module cut_hook() {
   // more testing
   union() {
      rotate_extrude(angle=angle,$fn=32)
         square(size=[radius,hook_width]);
      translate([0,-(hook_length+5),0])
         cube([radius,hook_length+5,hook_width]);
   }
}

// Body to union with the rounded top and front of the hook to make it solid
// (and printable).
//
module hook_body() {
   translate([0,0,-(hook_width/2)])
      difference() {
         translate([end_x,-hook_length,0])
            cube([slot_height+(radius-end_x),hook_length+end_y,hook_width]);
         translate([0,0,1])
            cut_hook();
         translate([0,0,-1])
            cut_hook();
      }
}

// Hook made up of rounded cylinder and torus to curve up a bit at the end.
//
module hook () {
   union() {
      // Straight part of hook.
      translate([radius,0.01,0])
         rotate([90,0,0])
            cylinder(r=hook_width/2,h=hook_length,$fn=32);
      // curved up at the end
      rotate_extrude(angle=angle,$fn=32)
         translate([radius,0,0])
            circle(d=hook_width, $fn=32);
      // nice rounded ball on end of hook
      rotate([0,0,angle])
         translate([radius,0,0])
            sphere(d=hook_width);
      // cylinder to provide rounded front end
      translate([end_x,end_y,0])
         rotate([0,90,0])
            cylinder(r=hook_width/2,h=slot_height+(radius-end_x));
      // Fill in body of hook leaving rounded surface on top and front
      hook_body();
      // Attach the connector on back of hook
      translate([50,-(17+hook_length-0.01),0])
         rotate([-90,0,0])
            connector(length=52,height=17);
      // Round off the end attaching to the connector
      translate([radius,-hook_length,0])
         sphere(d=hook_width, $fn=32);
   }
}

// rounded spool shape to subtract from hook body to punch holes
// to hang things on (or at least save plastic).
//
module spool() {
   // A nice cylinder with a torus subtracted from it to make rounded
   // holes.
   difference() {
      translate([0,0,-(hook_width/2)-1])
         cylinder(r=12,h=hook_width+2,$fn=32);
      rotate_extrude(angle=360,$fn=32)
         translate([((hook_width+3)/2)+8,0,0])
            circle(d=hook_width+3, $fn=32);
   }
}

// The hook with holes punched in the side.
//
module holy_hook() {
   // punch some holes in the side of the hook to use
   // less plastic and maybe hang something else on.
   difference() {
      hook();
      translate([84,5,0])
         spool();
      translate([84,-35,0])
         spool();
      translate([65,-15,0])
         spool();
      translate([60,17,0])
         spool();
   }
}

// Position hook for printing vertically
// (which will give loads of layers and take a couple of hours, but will
// print for maximum strength - I can be gluing the mag1 pieces together
// while it prints).
//
module vertical_hook() {
   rotate([0,90,0])
     translate([-(50+slot_height),0,0])
         holy_hook();
}

// As long as I'm going to spend two hours printing this, let's
// round the edges on the bottom as well. Gah! Printer program complains
// not manifold! Should I stick the side cylinders 0.01 into the torus
// or something? I can't quite imagine what the problem could be.
// Despite the complaint, the slicer seemed to work fine. (And openscad
// generated no complaints about manifold, just repetier complained)
//
module round_bottom() {
   translate([0,end_y,1.5])
   difference() {
      translate([-hook_width,-(hook_length+end_y),-5])
         cube([2*hook_width,hook_length+end_y+2*hook_width,5]);
      union() {
         translate([0,0,-1.5])
            cylinder(h=3,r=(hook_width-3)/2);
         rotate_extrude(angle=360,$fn=32)
            translate([(hook_width-3)/2,0,0])
               circle(d=3, $fn=32);
         translate([(hook_width-3)/2,0,0])
            rotate([90,0,0])
               cylinder(r=1.5,h=hook_length+end_y, $fn=32);
         translate([-(hook_width-3)/2,0,0])
            rotate([90,0,0])
               cylinder(r=1.5,h=hook_length+end_y, $fn=32);
         translate([-(hook_width-3)/2,-(hook_length+end_y),-1.5])
            cube([hook_width-3,hook_length+end_y,3]);
      }
   }
}

module rounded_vertical_hook() {
   difference() {
      vertical_hook();
      round_bottom();
   }
}

rounded_vertical_hook();
