// Amazingly, this fits absolutely perfectly on the first try, but the
// top needs to be a layer or two higher. I should probably use the magnet
// itself as a guide and drill holes, then scan the printed piece so I can
// pick off the hole locations.

include <mag1-frame.scad>

include <mag1-mag.scad>

include <mag1-holes.scad>

include <roundedcube.scad>

// Fiddle with the two magnet pieces to build a model of the complete
// magnet tall enough to cleanly subtract off the cube that will form
// the printed back piece of the sandwich.
//
module mag_and_frame() {
   difference() {
      // sink model down to right thickness above z==0
      translate([0,0,mag1_frame_thick-10])
         union() {
            // poke the magnet itself up above the frame by the correct
            // thickness and rotate and translate it to what looks like
            // the correct position.
            translate([9,40,10+mag1_mag_thick])
               rotate([0,180,181])
                  mag1_mag();
            // add in the frame to get complete magnet model.
            mag1_frame();
         }
      }
}

// Complete module for the back piece of the sandwich. The magnet and
// frame fits entirely in this and the front should be able to
// fit over it with a flat bottom on the print.
//
module mag1_back() {
   union() {
      // Need mirror image to match the magnet shape I'm holding in my
      // hand while looking at the preview :-).
      mirror([1,0,0])
         difference() {
            // make a cube to subtract the magnet shape from. In theory it
            // should then fit in the printed hollow.
            translate([-56,-4,0])
               difference() {
                  // Use a rounded cube to look nice
                  roundedcube(size=[60,56,2*(1+mag1_mag_thick+mag1_frame_thick)],
                              radius=1.5);
                  // and slice off the excees so the top is flat.
                  translate([-3,-3,1+mag1_mag_thick+mag1_frame_thick])
                     cube([70,70,50]);
               }
            // flip model over and raise it back up
            translate([0,0,mag1_mag_thick+mag1_frame_thick-0.01])
               rotate([0,180,0])
                  mag_and_frame();
         }
      // Add in the "holes" the fromt piece will fit over.
      translate([-4,-4,0])
         mag1_holes();
   }
}
